Print

Print


Commit in GeomConverter/src/org/lcsim/detector/converter/compact on MAIN
DetectorConverter.java+4-41.45 -> 1.46


GeomConverter/src/org/lcsim/detector/converter/compact
DetectorConverter.java 1.45 -> 1.46
diff -u -r1.45 -r1.46
--- DetectorConverter.java	29 Apr 2009 18:27:57 -0000	1.45
+++ DetectorConverter.java	1 May 2009 18:07:41 -0000	1.46
@@ -8,7 +8,7 @@
 import org.jdom.Element;
 import org.jdom.JDOMException;
 import org.lcsim.detector.DetectorElement;
-import org.lcsim.detector.DetectorElementStore;
+import org.lcsim.detector.DetectorStore;
 import org.lcsim.detector.IDetectorElement;
 import org.lcsim.detector.ILogicalVolume;
 import org.lcsim.detector.IPhysicalVolume;
@@ -49,8 +49,8 @@
 
     public IPhysicalVolume convert(Detector detector, Document doc)  throws JDOMException, IOException
     {        
-        // Clear out DetectorElement store before building new detector.
-        DetectorElementStore.getInstance().clear();
+        // Clear out old DetectorStore store before building new detector.
+        DetectorStore.getInstance().clear();
         
         // Convert materials.
         convertMaterials("/org/lcsim/material/elements.xml");
@@ -99,7 +99,7 @@
         addSubdetectorConverter(new PolyhedraEndcapCalorimeterConverter());
         addSubdetectorConverter(new EcalBarrelConverter());
         addSubdetectorConverter(new TubeSegmentConverter());
-        addSubdetectorConverter(new SiTrackerBarrel_sATLAS01Converter());
+        //addSubdetectorConverter(new SiTrackerBarrel_sATLAS01Converter());
     }
 
     private void addSubdetectorConverter(ISubdetectorConverter s)
CVSspam 0.2.8